# Predictions

Types:

```python
from fashn.types import PredictionRunResponse, PredictionStatusResponse
```

Methods:

- <code title="post /v1/run">client.predictions.<a href="./src/fashn/resources/predictions.py">run</a>(\*\*<a href="src/fashn/types/prediction_run_params.py">params</a>) -> <a href="./src/fashn/types/prediction_run_response.py">PredictionRunResponse</a></code>
- <code title="get /v1/status/{id}">client.predictions.<a href="./src/fashn/resources/predictions.py">status</a>(id) -> <a href="./src/fashn/types/prediction_status_response.py">PredictionStatusResponse</a></code>
